.. _install:

Install
~~~~~~~

This section describes how to install and configure the Networking-Ansible
Driver, code-named networking_ansible, on the controller node. This section
assumes that you already have a working OpenStack environment with Neutron
configured to provide VLAN tenant networking.

.. note::

   Note that installation and configuration may vary by distribution.

.. toctree::
   :maxdepth: 2

   install-obs.rst
   install-rdo.rst
   install-ubuntu.rst
   install-pip.rst
